class CadicaConstants:
    VIDEOS_DIR = "selectedVideos"
    INPUT_DIR = "input"
    PNG_EXT = ".png"
    LESION_VIDEOS_TXT = "lesionVideos.txt"
    NONLESION_VIDEOS_TXT = "nonlesionVideos.txt"
    SELECTED_FRAMES_TXT = "selectedFrames.txt"