class CadicaTestData:
    lesioned_image_paths_dict = {
        "p14/v1": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00011.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00012.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00013.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00014.png"
        ],
        "p14/v2": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v2/input/p14_v2_00016.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v2/input/p14_v2_00017.png"
        ],
        "p14/v10": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v10/input/p14_v10_00001.png"
        ],
        "p19/v6": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00012.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00013.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00014.png"
        ],
        "p19/v11": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00017.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00018.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00019.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00020.png"
        ],
        "p26/v1": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00020.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00021.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00022.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00023.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00024.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00025.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00026.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00027.png"
        ],
        "p26/v2": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00025.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00026.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00027.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00028.png"
        ]
    }

    nonlesioned_image_paths_dict = {
        "p4/v1": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00009.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00010.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00011.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00012.png"
        ],
        "p4/v5": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00012.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00013.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00014.png"
        ],
        "p19/v4": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00028.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00029.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00030.png"
        ],
        "p19/v9": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v9/input/p19_v9_00025.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v9/input/p19_v9_00026.png"
        ],
        "p26/v3": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v3/input/p26_v3_00016.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v3/input/p26_v3_00017.png"
        ],
        "p26/v5": [
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00016.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00017.png",
            "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00018.png"
        ],
    }

    lesioned_images_set = {
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00011.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00012.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00013.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v1/input/p14_v1_00014.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v2/input/p14_v2_00016.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v2/input/p14_v2_00017.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p14/v10/input/p14_v10_00001.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00012.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00013.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v6/input/p19_v6_00014.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00017.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00018.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00019.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v11/input/p19_v11_00020.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00020.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00021.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00022.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00023.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00024.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00025.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00026.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v1/input/p26_v1_00027.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00025.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00026.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00027.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v2/input/p26_v2_00028.png"
    }

    nonlesioned_images_set = {
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00009.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00010.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00011.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v1/input/p4_v1_00012.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00012.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00013.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p4/v5/input/p4_v5_00014.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00028.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00029.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v4/input/p19_v4_00030.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v9/input/p19_v9_00025.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p19/v9/input/p19_v9_00026.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v3/input/p26_v3_00016.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v3/input/p26_v3_00017.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00016.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00017.png",
        "/Users/abhaycuram/Desktop/ML Projects/Jeremy Fast AI/Python Scripts/cadica_data_set/tests/resources/valid_cadica_test_data_set/selectedVideos/p26/v5/input/p26_v5_00018.png"
    }